/****************************************************************************
* File: module.c                                                            *
* Description: ...                                                          *
*                                                                           *
* (C)Copyright altek Corporation 2003                                       *
*                                                                           *
* History:                                                                  *
*   2003/09/01; Somebody; Comment                                           *
*   2003/06/01; Somebody; Initial version                                   *
****************************************************************************/

/****************************************************************************
*                               Include File                                *
****************************************************************************/

#include <stdint.h>
#include <string.h>
#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h> 

#include "hal_uart.h"
#include "m_debugmsg.h"

/****************************************************************************
*                        Private Constant Definition                        *
****************************************************************************/
#define DBMSG_STRLEN    150

/****************************************************************************
*                          Private Type Declaration                         *
****************************************************************************/
struct __FILE { int handle; /* Add whatever you need here */ };

/****************************************************************************
*                        Private Function Prototype                         *
****************************************************************************/


/****************************************************************************
*                          Private Module Variable                          *
****************************************************************************/
static uint32_t  mEnable         = 0xdfffffff;         /* message enable mask */
static char   *msgString       = NULL;          /* formatted message string */



/****************************************************************************
*                              Public Function                              *
****************************************************************************/

/****************************************************************************/
/* Send a vsprintf-style string to the debug port                           */
/*                                                                          */
/* fmstring and ... arguments are passed to vsprintf() for formatting.      */
/*                                                                          */
/* bitmask: Debug message filter: Each major subsystem is provided with     */
/*          a 1-bit mask. Send message if that bit is set in the mEnable    */
/*          (message enable) filter.                                        */
/****************************************************************************/

void dbmsg_ftrace( uint32_t bitmask, char *fmtstring, ... )
{
  va_list vlist;	
	
	if( NULL == msgString )              /* if this is the first ftrace */
	{
			if( NULL == (msgString=(char*)malloc(DBMSG_STRLEN)) )
					return;
	}	
	
	if( mEnable & bitmask )
	{
		va_start( vlist, fmtstring ); 
		vsprintf( msgString, fmtstring, vlist );		
		printf( msgString );
	}
}

/****************************************************************************/
/* Get debug message enable mask.                                           */
/****************************************************************************/

uint32_t dbmsg_getmask( void )
{
    return mEnable;
}

/****************************************************************************/
/* Set debug message enable mask.                                           */
/*                                                                          */
/* Set enable mask for debug messages.                                      */
/*                                                                          */
/* bitmask: Identifies the source of the debug message to be enabled or     */
/*          disabled.                                                       */
/****************************************************************************/

void dbmsg_setmask( uint32_t bitmask )
{
    mEnable = bitmask | DBM_ALWAYS;
}


/****************************************************************************/
/* fputc implement for printf                                               */
/****************************************************************************/
int fputc(int ch, FILE * p_file) 
{
    hal_uart_put((uint8_t)ch);
    return 0;
}

/****************************************************************************
*                             Private Function                              *
****************************************************************************/



/******************************* End Of File *******************************/
